summaryrefslogtreecommitdiffstats
path: root/core/java/android/view/ActionMode.java
diff options
context:
space:
mode:
Diffstat (limited to 'core/java/android/view/ActionMode.java')
-rw-r--r--core/java/android/view/ActionMode.java18
1 files changed, 9 insertions, 9 deletions
diff --git a/core/java/android/view/ActionMode.java b/core/java/android/view/ActionMode.java
index 4b9b590..80dcecc 100644
--- a/core/java/android/view/ActionMode.java
+++ b/core/java/android/view/ActionMode.java
@@ -45,10 +45,10 @@ public abstract class ActionMode {
public static final int TYPE_FLOATING = 1;
/**
- * Default snooze time.
+ * Default value to hide the action mode for
+ * {@link ViewConfiguration#getDefaultActionModeHideDuration()}.
*/
- public static final int SNOOZE_TIME_DEFAULT =
- ViewConfiguration.getDefaultActionModeSnoozeTime();
+ public static final int DEFAULT_HIDE_DURATION = -1;
private Object mTag;
private boolean mTitleOptionalHint;
@@ -213,17 +213,17 @@ public abstract class ActionMode {
public void invalidateContentRect() {}
/**
* Hide the action mode view from obstructing the content below for a short period.
* This only makes sense for action modes that support dynamic positioning on the screen.
* If this method is called again before the snooze time expires, the later snooze will
* cancel the former and then take effect.
- * NOTE that there is an internal limit to how long the mode can be snoozed for. It's typically
+ * NOTE that there is an internal limit to how long the mode can be hidden for. It's typically
* about a few seconds.
*
* @param snoozeTime The number of milliseconds to snooze for.
* @see #SNOOZE_TIME_DEFAULT
*/
- public void snooze(int snoozeTime) {}
+ public void hide(long duration) {}
/**
* Finish and close this action mode. The action mode's {@link ActionMode.Callback} will
@@ -213,17 +213,17 @@ public abstract class ActionMode {
public void invalidateContentRect() {}
/**
- * Hide the action mode view from obstructing the content below for a short period.
+ * Hide the action mode view from obstructing the content below for a short duration.
* This only makes sense for action modes that support dynamic positioning on the screen.
@@ -213,17 +213,17 @@ public abstract class ActionMode {
* This only makes sense for action modes that support dynamic positioning on the screen.
- * If this method is called again before the snooze time expires, the later snooze will
+ * If this method is called again before the hide duration expires, the later hide call will
* cancel the former and then take effect.
@@ -213,17 +213,17 @@ public abstract class ActionMode {
* about a few seconds.
*
- * @param snoozeTime The number of milliseconds to snooze for.
- * @see #SNOOZE_TIME_DEFAULT
+ * @param duration The number of milliseconds to hide for.
+ * @see #DEFAULT_HIDE_DURATION
*/